# Credits

## Development Lead

-   [Lukas Heumos](mailto:lukas.heumos@posteo.net)
-   [Philipp Ehmele](mailto:philipp_ehm@protonmail.com)

## Contributors

-   Luke Zappia
-   Leon Hetzel
-   Nastja Horlava
-   Xinyue Zhang
